@@ -8,7 +8,8 @@ use crate::clarity::functions::NativeFunctions;
 use crate::clarity::types::{PrincipalData, QualifiedContractIdentifier, StandardPrincipalData};
 use crate::clarity::util::StacksAddress;
 use crate::clarity::variables::NativeVariables;
-use crate::contracts::{BNS_CONTRACT, COSTS_CONTRACT, POX_CONTRACT};
+use crate::clarity::errors::Error;
+use crate::contracts::{BNS_CONTRACT, COSTS_V1_CONTRACT, COSTS_V2_CONTRACT, POX_CONTRACT};
 use crate::repl::CostSynthesis;
 use crate::{clarity::diagnostic::Diagnostic, repl::settings::InitialContract};
 use ansi_term::{Colour, Style};
@@ -54,6 +55,7 @@ pub struct Session {
     pub coverage_reports: Vec<TestCoverageReport>,
     pub costs_reports: Vec<CostsReport>,
     pub initial_contracts_analysis: Vec<(ContractAnalysis, String, String)>,
+    pub show_costs: bool,
 }
 
 impl Session {
@@ -70,14 +72,15 @@ impl Session {
         Session {
             session_id: 0,
             started_at: 0,
-            settings,
+            interpreter: ClarityInterpreter::new(tx_sender, settings.costs_version),
             asts: BTreeMap::new(),
             contracts: BTreeMap::new(),
-            interpreter: ClarityInterpreter::new(tx_sender),
             api_reference: build_api_reference(),
             coverage_reports: vec![],
             costs_reports: vec![],
             initial_contracts_analysis: vec![],
+            show_costs: false,
+            settings,
         }
     }
 
@@ -184,92 +187,15 @@ impl Session {
             let boot_testnet_deployer =
                 PrincipalData::parse_standard_principal(&boot_testnet_address)
                     .expect("Unable to parse deployer's address");
-
             self.interpreter.set_tx_sender(boot_testnet_deployer);
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"pox".to_string())
-            {
-                self.formatted_interpretation(
-                    POX_CONTRACT.to_string(),
-                    Some("pox".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy POX");
-            }
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"bns".to_string())
-            {
-                self.formatted_interpretation(
-                    BNS_CONTRACT.to_string(),
-                    Some("bns".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy BNS");
-            }
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"costs".to_string())
-            {
-                self.formatted_interpretation(
-                    COSTS_CONTRACT.to_string(),
-                    Some("costs".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy COSTS");
-            }
+            self.include_boot_contracts();
 
             let boot_mainnet_address = "SP000000000000000000002Q6VF78";
             let boot_mainnet_deployer =
                 PrincipalData::parse_standard_principal(&boot_mainnet_address)
                     .expect("Unable to parse deployer's address");
             self.interpreter.set_tx_sender(boot_mainnet_deployer);
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"pox".to_string())
-            {
-                self.formatted_interpretation(
-                    POX_CONTRACT.to_string(),
-                    Some("pox".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy POX");
-            }
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"bns".to_string())
-            {
-                self.formatted_interpretation(
-                    BNS_CONTRACT.to_string(),
-                    Some("bns".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy BNS");
-            }
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"costs".to_string())
-            {
-                self.formatted_interpretation(
-                    COSTS_CONTRACT.to_string(),
-                    Some("costs".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy COSTS");
-            }
+            self.include_boot_contracts();
             self.interpreter.set_tx_sender(default_tx_sender);
         }
 
@@ -329,7 +255,7 @@ impl Session {
 
                 match self
                     .interpreter
-                    .credit_stx_balance(recipient, account.balance)
+                    .mint_stx_balance(recipient, account.balance)
                 {
                     Ok(_) => {}
                     Err(err) => output_err.push(red!(err)),
@@ -411,6 +337,61 @@ impl Session {
         }
     }
 
+    pub fn include_boot_contracts(&mut self) {
+        if self
+            .settings
+            .include_boot_contracts
+            .contains(&"pox".to_string())
+        {
+            self.formatted_interpretation(
+                POX_CONTRACT.to_string(),
+                Some("pox".to_string()),
+                false,
+                None,
+            )
+            .expect("Unable to deploy POX");
+        }
+        if self
+            .settings
+            .include_boot_contracts
+            .contains(&"bns".to_string())
+        {
+            self.formatted_interpretation(
+                BNS_CONTRACT.to_string(),
+                Some("bns".to_string()),
+                false,
+                None,
+            )
+            .expect("Unable to deploy BNS");
+        }
+        if self
+            .settings
+            .include_boot_contracts
+            .contains(&"costs-v1".to_string())
+        {
+            self.formatted_interpretation(
+                COSTS_V1_CONTRACT.to_string(),
+                Some("costs-v1".to_string()),
+                false,
+                None,
+            )
+            .expect("Unable to deploy COSTS");
+        }
+        if self
+            .settings
+            .include_boot_contracts
+            .contains(&"costs-v2".to_string())
+        {
+            self.formatted_interpretation(
+                COSTS_V2_CONTRACT.to_string(),
+                Some("costs-v2".to_string()),
+                false,
+                None,
+            )
+            .expect("Unable to deploy COSTS");
+        }
+    }
+
     #[cfg(feature = "wasm")]
     pub async fn start_wasm(&mut self) -> String {
         let mut output = Vec::<String>::new();
@@ -422,92 +403,16 @@ impl Session {
             let boot_testnet_deployer =
                 PrincipalData::parse_standard_principal(&boot_testnet_address)
                     .expect("Unable to parse deployer's address");
-
             self.interpreter.set_tx_sender(boot_testnet_deployer);
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"pox".to_string())
-            {
-                self.formatted_interpretation(
-                    POX_CONTRACT.to_string(),
-                    Some("pox".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy POX");
-            }
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"bns".to_string())
-            {
-                self.formatted_interpretation(
-                    BNS_CONTRACT.to_string(),
-                    Some("bns".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy BNS");
-            }
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"costs".to_string())
-            {
-                self.formatted_interpretation(
-                    COSTS_CONTRACT.to_string(),
-                    Some("costs".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy COSTS");
-            }
+            self.include_boot_contracts();
 
             let boot_mainnet_address = "SP000000000000000000002Q6VF78";
             let boot_mainnet_deployer =
                 PrincipalData::parse_standard_principal(&boot_mainnet_address)
                     .expect("Unable to parse deployer's address");
             self.interpreter.set_tx_sender(boot_mainnet_deployer);
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"pox".to_string())
-            {
-                self.formatted_interpretation(
-                    POX_CONTRACT.to_string(),
-                    Some("pox".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy POX");
-            }
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"bns".to_string())
-            {
-                self.formatted_interpretation(
-                    BNS_CONTRACT.to_string(),
-                    Some("bns".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy BNS");
-            }
-            if self
-                .settings
-                .include_boot_contracts
-                .contains(&"costs".to_string())
-            {
-                self.formatted_interpretation(
-                    COSTS_CONTRACT.to_string(),
-                    Some("costs".to_string()),
-                    false,
-                    None,
-                )
-                .expect("Unable to deploy COSTS");
-            }
+            self.include_boot_contracts();
+
             self.interpreter.set_tx_sender(default_tx_sender);
         }
 
@@ -595,14 +500,23 @@ impl Session {
             cmd if cmd.starts_with("::advance_chain_tip") => {
                 self.parse_and_advance_chain_tip(&mut output, cmd)
             }
+            cmd if cmd.starts_with("::toggle_costs") => self.toggle_costs(&mut output),
 
             snippet => {
-                let mut result =
-                    match self.formatted_interpretation(snippet.to_string(), None, true, None) {
+                if self.show_costs {
+                    self.get_costs(&mut output, &format!("::get_costs {}", snippet))
+                } else {
+                    let mut result = match self.formatted_interpretation(
+                        snippet.to_string(),
+                        None,
+                        true,
+                        None,
+                    ) {
                         Ok((result, _)) => result,
                         Err(result) => result,
                     };
-                output.append(&mut result);
+                    output.append(&mut result);
+                }
             }
         }
         output
@@ -617,7 +531,7 @@ impl Session {
     ) -> Result<(Vec<String>, ExecutionResult), Vec<String>> {
         let light_red = Colour::Red.bold();
 
-        let result = self.interpret(snippet.to_string(), name, cost_track, test_name);
+        let result = self.interpret(snippet.to_string(), name.clone(), cost_track, test_name);
         let mut output = Vec::<String>::new();
 
         match result {
@@ -637,7 +551,10 @@ impl Session {
                 }
                 Ok((output, result))
             }
-            Err((message, diagnostic)) => {
+            Err((message, diagnostic, _)) => {
+                if let Some(name) = name {
+                    output.push(format!("Error found in contract {}", name)); 
+                }
                 output.push(red!(message));
                 if let Some(diagnostic) = diagnostic {
                     if diagnostic.spans.len() > 0 {
@@ -700,7 +617,7 @@ impl Session {
         args: &Vec<String>,
         sender: &str,
         test_name: String,
-    ) -> Result<ExecutionResult, (String, Option<Diagnostic>)> {
+    ) -> Result<ExecutionResult, (String, Option<Diagnostic>, Option<Error>)> {
         let initial_tx_sender = self.get_tx_sender();
         // Kludge for handling fully qualified contract_id vs sugared syntax
         let first_char = contract.chars().next().unwrap();
@@ -738,7 +655,7 @@ impl Session {
         name: Option<String>,
         cost_track: bool,
         test_name: Option<String>,
-    ) -> Result<ExecutionResult, (String, Option<Diagnostic>)> {
+    ) -> Result<ExecutionResult, (String, Option<Diagnostic>, Option<Error>)> {
         let (contract_name, is_tx) = match name {
             Some(name) => (name, false),
             None => (format!("contract-{}", self.contracts.len()), true),
@@ -849,6 +766,10 @@ impl Session {
             "{}",
             help_colour.paint("::advance_chain_tip <count>\t\tSimulate mining of <count> blocks")
         ));
+        output.push(format!(
+            "{}",
+            help_colour.paint("::toggle_costs\t\t\t\tDisplay cost analysis after every expression")
+        ))
     }
 
     fn parse_and_advance_chain_tip(&mut self, output: &mut Vec<String>, command: &str) {
@@ -926,6 +847,11 @@ impl Session {
         self.interpreter.get_assets_maps()
     }
 
+    pub fn toggle_costs(&mut self, output: &mut Vec<String>) {
+        self.show_costs = !self.show_costs;
+        output.push(green!(format!("Always show costs: {}", self.show_costs)))
+    }
+
     #[cfg(feature = "cli")]
     pub fn get_costs(&mut self, output: &mut Vec<String>, cmd: &str) {
         let snippet = cmd.to_string().split_off("::get_costs ".len());
@@ -1011,9 +937,8 @@ impl Session {
             table.add_row(row!["Contract identifier", "Public functions"]);
             let contracts = self.contracts.clone();
             for (contract_id, methods) in contracts.iter() {
-                if !contract_id.ends_with(".pox")
-                    && !contract_id.ends_with(".bns")
-                    && !contract_id.ends_with(".costs")
+                if !contract_id.starts_with("ST000000000000000000002AMW42H")
+                    && !contract_id.starts_with("SP000000000000000000002Q6VF78")
                 {
                     let mut formatted_methods = vec![];
                     for (method_name, method_args) in methods.iter() {
@@ -1103,7 +1028,7 @@ impl Session {
             }
         };
 
-        match self.interpreter.credit_stx_balance(recipient, amount) {
+        match self.interpreter.mint_stx_balance(recipient, amount) {
             Ok(msg) => output.push(green!(msg)),
             Err(err) => output.push(red!(err)),
         };
